<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="nl_NL">
<context>
    <name>AddServerDialog</name>
    <message>
        <location filename="ui/serverdialog.cpp" line="137"/>
        <source>Add a new server</source>
        <translation type="unfinished">Voeg een nieuwe server toe</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="140"/>
        <source>Server name</source>
        <translation type="obsolete">Servernaam</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="145"/>
        <source>Path</source>
        <translation type="unfinished">Server adres</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="150"/>
        <source>Add</source>
        <translation>Voeg toe</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="152"/>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="140"/>
        <source>Name</source>
        <translation type="unfinished">Naam</translation>
    </message>
</context>
<context>
    <name>BrowseDialog</name>
    <message>
        <location filename="ui/browsedialog.cpp" line="75"/>
        <source>Parent Directory</source>
        <translation type="obsolete">Bovenliggende map</translation>
    </message>
    <message>
        <location filename="ui/browsedialog.cpp" line="83"/>
        <source>List View</source>
        <translation type="obsolete">Lijst</translation>
    </message>
    <message>
        <location filename="ui/browsedialog.cpp" line="91"/>
        <source>Detail View</source>
        <translation type="obsolete">Details</translation>
    </message>
    <message>
        <location filename="ui/browsedialog.cpp" line="99"/>
        <source>Look in:</source>
        <translation type="obsolete">Locatie:</translation>
    </message>
    <message>
        <location filename="ui/browsedialog.cpp" line="104"/>
        <source>Open</source>
        <translation type="obsolete">Open</translation>
    </message>
    <message>
        <location filename="ui/browsedialog.cpp" line="109"/>
        <source>Cancel</source>
        <translation type="obsolete">Annuleer</translation>
    </message>
</context>
<context>
    <name>CollectionInfoModel</name>
    <message>
        <location filename="lib/collectioninfomodel.cpp" line="73"/>
        <source>[ All ]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="ui/filedialog.cpp" line="58"/>
        <source>Select music files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/filedialog.cpp" line="75"/>
        <source>Select music directory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InfoWindow</name>
    <message>
        <location filename="ui/infowindow.cpp" line="41"/>
        <source>Esperanza - Info</source>
        <translation>Esperanza - Informatie</translation>
    </message>
</context>
<context>
    <name>KeyInputDialog</name>
    <message>
        <location filename="ui/preferencessupport.cpp" line="60"/>
        <source>Press a key:</source>
        <translation type="unfinished">Druk een toets als sneltoest:</translation>
    </message>
    <message>
        <location filename="ui/preferencessupport.cpp" line="94"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <location filename="ui/preferencessupport.cpp" line="69"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="ui/preferencessupport.cpp" line="70"/>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
</context>
<context>
    <name>KeyWidget</name>
    <message>
        <location filename="ui/preferencessupport.cpp" line="119"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
</context>
<context>
    <name>LastFmDialog</name>
    <message>
        <location filename="ui/lastfm.cpp" line="48"/>
        <source>Similar artists to:</source>
        <translation>Artiesten zoals:</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="52"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="67"/>
        <source>No data ...</source>
        <translation>Geen gegevens ...</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="116"/>
        <source>Search for in Medialib</source>
        <translation type="obsolete">Zoek naar in bibliotheek</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="124"/>
        <source>Open artist at Last.fm</source>
        <translation type="obsolete">Open artiest op Last.fm</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="127"/>
        <source>Open artist at Musicbrainz</source>
        <translation type="obsolete">Open artiest op Musicbrainz</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="131"/>
        <source>Search for artist on oink</source>
        <translation type="obsolete">Zoek naar artiest op oink</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="217"/>
        <source>Error - try again</source>
        <translation>Fout - Probeer opnieuw</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="302"/>
        <source>Loading data</source>
        <translation>Gegevens worden geladen</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="132"/>
        <source>Artists that are similar to ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="137"/>
        <source>Most played tracks by ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="142"/>
        <source>Most played albums by ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="176"/>
        <source>Open artist page at Last.fm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="179"/>
        <source>Open artist page at Musicbrainz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="183"/>
        <source>Search for artist on OiNK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MedialibDialog</name>
    <message>
        <location filename="ui/medialibdialog.cpp" line="54"/>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="55"/>
        <source>Artist</source>
        <translation>Artiest</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="56"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="57"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="58"/>
        <source>Year</source>
        <translation>Jaar</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="63"/>
        <source>=</source>
        <translation>=</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="82"/>
        <source>Display non-available entries</source>
        <translation type="obsolete">Toon onbeschikbare nummers</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="99"/>
        <source>Display unavailable entries</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniMode</name>
    <message>
        <location filename="ui/minimode.cpp" line="36"/>
        <source>Esperanza</source>
        <translation>Esperanza</translation>
    </message>
</context>
<context>
    <name>PaneBrowserView</name>
    <message>
        <location filename="ui/panebrowserview.cpp" line="72"/>
        <source>[ All ]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlayerWidget</name>
    <message>
        <location filename="ui/playerwidget.cpp" line="171"/>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="468"/>
        <source>Preferences</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="173"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="174"/>
        <source>Playlist</source>
        <translation>Speellijst</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="414"/>
        <source>Add local file</source>
        <translation>Voeg lokaal bestand toe</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="415"/>
        <source>Add local dir</source>
        <translation>Voeg lokale map toe</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="409"/>
        <source>Add remote file</source>
        <translation type="obsolete">Voeg remote bestand toe</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="411"/>
        <source>Add files from medialib</source>
        <translation type="obsolete">Voeg bestanden uit bibliotheek toe</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="181"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="182"/>
        <source>Esperanza Help</source>
        <translation>Esperanza - Help</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="430"/>
        <source>Last.fm browser</source>
        <translation>Last.fm browser</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="470"/>
        <source>Shuffle</source>
        <translation>Willekeurig afspelen</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="434"/>
        <source>Keyboard shortcuts</source>
        <translation>Sneltoetsen</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="565"/>
        <source>Remove selected files</source>
        <translation>Verwijder geselecteerde bestanden</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="566"/>
        <source>Clear playlist</source>
        <translation>Leeg speellijst</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="591"/>
        <source>Server died. The application will now quit.</source>
        <translation type="obsolete">De server is gestopt. Esperanza wordt nu gestopt.</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="690"/>
        <source>Esperanza is now playing:</source>
        <translation>Esperanza speelt nu:</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="416"/>
        <source>Search medialib</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="421"/>
        <source>Add URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="431"/>
        <source>Stream directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="435"/>
        <source>About Esperanza</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="517"/>
        <source>URL dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="517"/>
        <source>Enter URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="629"/>
        <source>Server died. Esperanza will close.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferenceDialog</name>
    <message>
        <location filename="ui/preferences.cpp" line="102"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="103"/>
        <source>Value</source>
        <translation>Waarde</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="118"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="122"/>
        <source>Discard</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="125"/>
        <source>Reset</source>
        <translation>Herstel</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="259"/>
        <source>Reset settings?</source>
        <translation>Instellingen herstellen?</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="258"/>
        <source>Are your sure you want to reset program to standard values?</source>
        <translation type="obsolete">Weet u zeker dat u de standaard instellingen wilt herstellen?</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="261"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="261"/>
        <source>No</source>
        <translation>Nee</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="44"/>
        <source>Autostart xmms2d if it&apos;s not running</source>
        <translation type="unfinished">Autostart xmms2d wanneer deze niet draait</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="45"/>
        <source>Number of songs to randomly add</source>
        <translation type="obsolete">Aantal nummers dat willekeurig wordt toegevoegd</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="47"/>
        <source>Ignore locale settings and use default language</source>
        <translation>Negeer taal instellingen en gebruik standaard taal</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="47"/>
        <source>Show serverbrowser on startup</source>
        <translation type="obsolete">Toon serverbrowser bij het opstarten</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="48"/>
        <source>Show the server browser on startup</source>
        <translation type="unfinished">Spring naar huidige nummer bij nummerwissel</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="49"/>
        <source>Jump to the current entry in the playlist on song change</source>
        <translation type="unfinished">Gebruik compacte (saaie) speellijst modus</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="50"/>
        <source>Show albumart under artist</source>
        <translation type="obsolete">Toon album afbeelding onder artiest</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="51"/>
        <source>Show album art under artist</source>
        <translation type="unfinished">Toon ook een stop knop</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="52"/>
        <source>Use reversed elapsed time</source>
        <translation type="obsolete">Gebruik aflopende tijd</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="53"/>
        <source>Show time remaining instead of elapsed</source>
        <translation type="unfinished">Grootte van album afbeelding cache in kb</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="54"/>
        <source>Size of album art cache in kB</source>
        <translation type="unfinished">Te tonen waardes in context rij (komma gescheiden)</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="55"/>
        <source>Information to be shown in the context area</source>
        <translation type="unfinished">Toon het contextvak in een felle kleur</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="56"/>
        <source>Draw the context area in a lighter color</source>
        <translation type="unfinished">Toon de verloop balk in een lichte kleur</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="57"/>
        <source>Show volume in a popup</source>
        <translation type="obsolete">Toon het volume in een popup</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="58"/>
        <source>Show the volume slider in a popup</source>
        <translation type="unfinished">Verander volume interactief, kan problemen veroorzaken.</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="59"/>
        <source>Change volume interactively (could cause problems)</source>
        <translation type="unfinished">Toon oink zoeken in last.fm scherm</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="61"/>
        <source>Show system tray icon</source>
        <translation type="obsolete">Toon systeem icoon</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="62"/>
        <source>Show notification on song change</source>
        <translation type="obsolete">Toon notificatie bij nummer wissel</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="45"/>
        <source>Ignore the desktop settings (use this if everything is black)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="50"/>
        <source>Use compact playlist mode (no context area)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="52"/>
        <source>Show a stop button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="57"/>
        <source>Paint the progress bar in a lighter color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="60"/>
        <source>Show OiNK search in Last.FM view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="61"/>
        <source>Load artists and albums for completion in Medialib window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="63"/>
        <source>Show icon in system tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="64"/>
        <source>Show popup notification on song change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="260"/>
        <source>Are your sure you want to reset the preferences to default values?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ServerDialog</name>
    <message>
        <location filename="ui/serverdialog.cpp" line="40"/>
        <source>Welcome to Esperanza
Please select a server to connect to.
You may disable this dialog in the preferences.</source>
        <translation type="unfinished">Welkom bij een XMMS2 client
Selecteer de server waarmee verbinding moet worden gemaakt.
Het is mogelijk om deze dialoog uit te schakelen in de instellingen</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="73"/>
        <source>Connect</source>
        <translation type="unfinished">verbindt</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="77"/>
        <source>Quit</source>
        <translation type="unfinished">sluit</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="168"/>
        <source>Sorry, that name is already taken.</source>
        <translation type="unfinished">Die naam is al in gebruik!</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="186"/>
        <source>Sorry, you can&apos;t remove autodetected servers!</source>
        <translation type="unfinished">Kan geen mDNS server verwijderen!</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="192"/>
        <source>Sorry, you can&apos;t remove the local server!</source>
        <translation type="unfinished">Kan geen lokaal item verwijderen!</translation>
    </message>
</context>
<context>
    <name>StreamingDialog</name>
    <message>
        <location filename="ui/streamingdialog.cpp" line="41"/>
        <source>Esperanza - Stream Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="50"/>
        <source>My bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="52"/>
        <source>Last.Fm radio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="54"/>
        <source>Icecast directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="92"/>
        <source>Bookmark this URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="93"/>
        <source>URL:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamingIcecast</name>
    <message>
        <location filename="ui/streamingdialog.cpp" line="326"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="161"/>
        <source>Reset</source>
        <translation type="unfinished">Herstel</translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="190"/>
        <source>Add to playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="191"/>
        <source>Add to bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="239"/>
        <source>Name</source>
        <translation type="unfinished">Naam</translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="240"/>
        <source>Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="241"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="318"/>
        <source>Downloading</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SystemTray</name>
    <message>
        <location filename="ui/systemtray.cpp" line="42"/>
        <source>Nothing</source>
        <translation>Niets</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="91"/>
        <source>Hide main window</source>
        <translation>Verberg hoofdvenster</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="47"/>
        <source>Play/Pause</source>
        <translation>Afspelen/Pause</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="51"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="55"/>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="57"/>
        <source>Previous</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="60"/>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="84"/>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="87"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="90"/>
        <source>Show main window</source>
        <translation>Toon hoofdvenster</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="ui/textdialog.cpp" line="33"/>
        <source>Close</source>
        <translation>Afsluiten</translation>
    </message>
</context>
</TS>
